import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { getStyles } from './Breadcrumb.styles';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Link } from '../Link';
import { Icon } from '../Icon';
const getClassNames = classNamesFunction();
let BreadcrumbBase = class BreadcrumbBase extends BaseComponent {
    get classNames() {
        const { className, theme } = this;
        return getClassNames(getStyles, {
            theme,
            className,
        });
    }
    onBreadcrumbClicked(event, item) {
        if (item.onClick) {
            item.onClick(event, item);
        }
    }
    render(h) {
        const { classNames, items } = this;
        return h('div', { class: classNames.root, attrs: { role: 'navigation' } }, [
            h('ol', { class: classNames.list }, items.map((item, index) => h('li', {
                key: index,
                class: classNames.listItem,
            }, [
                (item.onClick || item.href)
                    ? h(Link, {
                        class: classNames.itemLink,
                        attrs: { href: item.href },
                        on: {
                            click: ev => this.onBreadcrumbClicked(ev, item),
                        },
                    }, item.text)
                    : h('span', {
                        class: classNames.item,
                        on: {
                            click: ev => this.onBreadcrumbClicked(ev, item),
                        },
                    }, item.text),
                (index !== (items.length - 1)) && h(Icon, {
                    key: `icon-${index}`,
                    class: classNames.chevron,
                    attrs: {
                        iconName: 'ChevronRight',
                    },
                }),
            ]))),
        ]);
    }
};
__decorate([
    Prop({ type: Array, required: true }),
    __metadata("design:type", Array)
], BreadcrumbBase.prototype, "items", void 0);
BreadcrumbBase = __decorate([
    Component
], BreadcrumbBase);
export { BreadcrumbBase };
//# sourceMappingURL=Breadcrumb.base.js.map