import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { getBaseButtonClassNames } from './BaseButton.classNames';
import { Icon, FontIcon } from '../Icon';
import { DirectionalHint } from '../../common/DirectionalHint';
import { ContextualMenu } from '../ContextualMenu';
const TouchIdleDelay = 500; /* ms */
let BaseButton = class BaseButton extends BaseComponent {
    constructor() {
        super(...arguments);
        this.menuHidden = true;
        this.menuOpen = false;
    }
    get MenuType() {
        return this.menuAs || ContextualMenu;
    }
    get component() {
        const { disabled, href } = this;
        const renderAsAnchor = !disabled && !!href;
        return renderAsAnchor ? 'a' : 'button';
    }
    get isSplitButton() {
        return !!this.menuProps && this.split === true;
    }
    get shouldRenderMenu() {
        const { menuHidden } = this;
        const { persistMenu, renderPersistedMenuHiddenOnMount } = this;
        if (!menuHidden) {
            // Always should render a menu when it is expanded
            return true;
        }
        else if (persistMenu && (false || renderPersistedMenuHiddenOnMount)) {
            // _renderedVisibleMenu ensures that the first rendering of
            // the menu happens on-screen, as edge's scrollbar calculations are off if done while hidden.
            return true;
        }
        return false;
    }
    get classNames() {
        const { theme, styles, className, iconProps, menuIconProps, variantClassName, disabled, primaryDisabled, checked, getClassNames } = this;
        const isPrimaryButtonDisabled = disabled || primaryDisabled;
        return getClassNames
            ? getClassNames(theme, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, checked, !this.menuHidden, !!this.menuProps, this.split, !!this.allowDisabledFocus)
            : getBaseButtonClassNames(theme, styles, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, !!this.menuProps, checked, !this.menuHidden, this.split);
    }
    render(h) {
        const ButtonComponent = this.component;
        const MenuComponent = this.MenuType;
        const { classNames, href, iconProps, className, css, secondaryText, isSplitButton, menuProps, menuIconProps, shouldRenderMenu } = this;
        return h(ButtonComponent, {
            ref: 'buttonElement',
            class: classNames.root,
            attrs: { href },
            on: {
                click: ev => this.$emit('click', ev),
            },
        }, [
            h('span', { class: classNames.flexContainer }, [
                iconProps && h(Icon, {
                    class: css(classNames.icon, className),
                    props: iconProps,
                }),
                this.$scopedSlots.flex && this.$scopedSlots.flex({}),
                this.$scopedSlots.default && h('span', { class: classNames.textContainer }, [
                    h('span', { class: classNames.label }, this.$scopedSlots.default({})),
                    secondaryText && h('span', { class: classNames.description }, secondaryText),
                ]),
                (!isSplitButton && menuProps) && h(FontIcon, {
                    class: classNames.menuIcon,
                    attrs: {
                        iconName: 'ChevronDown',
                    },
                    props: menuIconProps,
                }),
                (menuProps && !menuProps.doNotLayer && shouldRenderMenu) && h(MenuComponent, {
                    class: css('ms-BaseButton-menuhost', menuProps.className),
                    attrs: {
                        directionalHint: DirectionalHint.bottomLeftEdge,
                        target: isSplitButton ? this.$refs.splitButtonContainer : this.$refs.buttonElement,
                    },
                    props: menuProps,
                    on: {
                        dismiss: () => (this.menuHidden = true),
                    },
                }),
            ]),
        ]);
    }
};
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], BaseButton.prototype, "href", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "checked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "split", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "primaryDisabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "allowDisabledFocus", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], BaseButton.prototype, "variantClassName", void 0);
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], BaseButton.prototype, "iconProps", void 0);
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], BaseButton.prototype, "menuIconProps", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], BaseButton.prototype, "menuAs", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], BaseButton.prototype, "menuProps", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "persistMenu", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], BaseButton.prototype, "renderPersistedMenuHiddenOnMount", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], BaseButton.prototype, "secondaryText", void 0);
__decorate([
    Prop({ type: Function, default: null }),
    __metadata("design:type", Function)
], BaseButton.prototype, "getClassNames", void 0);
BaseButton = __decorate([
    Component
], BaseButton);
export { BaseButton };
//# sourceMappingURL=BaseButton.js.map