import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { positionCallout } from '../../utilities/positioning';
import { clickedOutside } from '../../utilities/clickedOutside';
const getClassNames = classNamesFunction();
let CalloutContentBase = class CalloutContentBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalKey = new Date();
        this.positions = null;
        this.positionAttempts = 0;
    }
    created() {
        window.addEventListener('click', this.onGlobalClick, true);
        window.addEventListener('scroll', this.onGlobalScroll, true);
    }
    beforeDestroy() {
        window.removeEventListener('click', this.onGlobalClick, true);
        window.removeEventListener('scroll', this.onGlobalScroll, true);
    }
    updated() {
        this.internalKey = new Date();
    }
    mounted() {
        this.updatePosition();
    }
    get classNames() {
        const { theme, className, calloutMaxWidth, backgroundColor, finalHeight, positions, styles, calloutWidth, beakWidth } = this;
        return getClassNames(styles, {
            theme: theme,
            className,
            overflowYHidden: !!finalHeight,
            calloutWidth,
            positions,
            beakWidth,
            backgroundColor,
            calloutMaxWidth,
        });
    }
    get actualBeakWidth() {
        return Math.sqrt(this.beakWidth * this.beakWidth * 2);
    }
    get positionCss() {
        if (!this.positions)
            return null;
        const positionCss = this.positions;
        for (const key in positionCss.elementPosition) {
            positionCss.elementPosition[key] = `${positionCss.elementPosition[key]}px`;
        }
        for (const key in positionCss.beakPosition.elementPosition) {
            positionCss.beakPosition.elementPosition[key] = `${positionCss.beakPosition.elementPosition[key]}px`;
        }
        return positionCss;
    }
    updatePosition() {
        const positions = this.positions;
        const currentProps = { ...this.$props };
        currentProps.bounds = this.bounds;
        currentProps.target = this.target;
        const newPositions = positionCallout(currentProps, this.$refs.hostElement, this.$refs.calloutElement, this.positions);
        if ((!positions && newPositions) ||
            (positions && newPositions && !this._arePositionsEqual(positions, newPositions) && this.positionAttempts < 5)) {
            this.positionAttempts++;
            this.positions = newPositions;
        }
        else if (this.positionAttempts > 0) {
            this.positionAttempts = 0;
            this.$emit('positioned', this.positions);
        }
    }
    onGlobalClick(e) {
        const outside = clickedOutside(e, this.$refs.calloutElement);
        if (outside)
            this.$emit('dismiss', true);
    }
    onGlobalScroll(e) {
        this.$emit('dismiss', true);
    }
    get bounds() {
        return {
            top: 0 + this.minPagePadding,
            left: 0 + this.minPagePadding,
            right: window.innerWidth - this.minPagePadding,
            bottom: window.innerHeight - this.minPagePadding,
            width: window.innerWidth - this.minPagePadding * 2,
            height: window.innerHeight - this.minPagePadding * 2,
        };
    }
    _arePositionsEqual(positions, newPosition) {
        return (this._comparePositions(positions.elementPosition, newPosition.elementPosition) &&
            this._comparePositions(positions.beakPosition.elementPosition, newPosition.beakPosition.elementPosition));
    }
    _comparePositions(oldPositions, newPositions) {
        for (const key in newPositions) {
            // This needs to be checked here and below because there is a linting error if for in does not immediately have an if statement
            if (newPositions.hasOwnProperty(key)) {
                const oldPositionEdge = oldPositions[key];
                const newPositionEdge = newPositions[key];
                if (oldPositionEdge !== undefined && newPositionEdge !== undefined) {
                    if (oldPositionEdge.toFixed(2) !== newPositionEdge.toFixed(2)) {
                        return false;
                    }
                }
                else {
                    return false;
                }
            }
        }
        return true;
    }
    render(h) {
        const { classNames, positionCss, isBeakVisible } = this;
        return h('div', {
            ref: 'hostElement',
            class: classNames.container,
        }, [
            h('div', {
                ref: 'calloutElement',
                class: classNames.root,
                style: positionCss ? positionCss.elementPosition : null,
            }, [
                isBeakVisible && h('div', {
                    class: classNames.beak,
                    style: (positionCss && positionCss.beakPosition) ? positionCss.beakPosition.elementPosition : null,
                }),
                isBeakVisible && h('div', { class: classNames.beakCurtain }),
                h('div', { class: classNames.calloutMain }, [
                    this.$slots.default,
                ]),
            ]),
        ]);
    }
};
__decorate([
    Prop({ type: HTMLElement, required: true }),
    __metadata("design:type", HTMLElement)
], CalloutContentBase.prototype, "target", void 0);
__decorate([
    Prop({ type: Number, default: null }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "calloutWidth", void 0);
__decorate([
    Prop({ type: Number, default: 16 }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "beakWidth", void 0);
__decorate([
    Prop({ type: Number, default: 8 }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "minPagePadding", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], CalloutContentBase.prototype, "isBeakVisible", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CalloutContentBase.prototype, "coverTarget", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "gapSpace", void 0);
__decorate([
    Prop({ type: Number, default: undefined }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "finalHeight", void 0);
__decorate([
    Prop({ type: Number, default: undefined }),
    __metadata("design:type", Number)
], CalloutContentBase.prototype, "calloutMaxWidth", void 0);
__decorate([
    Prop({ type: String, default: undefined }),
    __metadata("design:type", String)
], CalloutContentBase.prototype, "backgroundColor", void 0);
CalloutContentBase = __decorate([
    Component
], CalloutContentBase);
export { CalloutContentBase };
//# sourceMappingURL=CalloutContent.base.js.map