import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch, Model } from 'vue-property-decorator';
import { Label } from '../../Label';
import { Icon } from '../../Icon';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let CheckboxBase = class CheckboxBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalValue = this.checked || this.defaultChecked;
        this.isIndeterminate = this.indeterminate || this.defaultIndeterminate;
    }
    onCheckedChanged(newVal) {
        this.internalValue = newVal;
    }
    render(h) {
        const { classNames, title, label } = this;
        const $input = h('input', {
            class: classNames.input,
            attrs: {
                id: `Checkbox${this.uid}`,
                ...this.$attrs,
                disabled: this.disabled,
                type: 'checkbox',
            },
            on: {
                input: this.onInput,
            },
        });
        const $icon = h(Icon, {
            class: classNames.checkmark,
            attrs: {
                iconName: 'CheckMark',
            },
        });
        const $checkbox = h('div', { class: classNames.checkbox }, [$icon]);
        const $text = (label || this.$slots.default) && h('span', {
            class: classNames.text,
            attrs: {
                title: title,
            },
        }, this.$slots.default || label);
        return h('div', { class: classNames.root }, [
            $input,
            h(Label, {
                class: classNames.label,
                attrs: { for: `Checkbox${this.uid}` },
            }, [
                $checkbox,
                $text,
            ]),
        ]);
    }
    get classNames() {
        const { theme, className, disabled, isIndeterminate, internalValue, boxSide } = this;
        return getClassNames(this.styles, {
            theme,
            className,
            disabled,
            indeterminate: isIndeterminate,
            checked: internalValue,
            reversed: boxSide !== 'start',
            isUsingCustomLabelRender: true,
        });
    }
    onInput() {
        if (this.disabled)
            return;
        if (this.isIndeterminate) {
            this.internalValue = this.defaultChecked;
            this.isIndeterminate = false;
        }
        else {
            this.internalValue = !this.internalValue;
        }
        this.$emit('input', this.internalValue);
    }
};
__decorate([
    Model('input', { type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "checked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "defaultChecked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "indeterminate", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "defaultIndeterminate", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "required", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "label", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "title", void 0);
__decorate([
    Prop({ type: String, default: 'start', validator: v => ['start', 'end'].indexOf(v) > -1 }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "boxSide", void 0);
__decorate([
    Watch('checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean]),
    __metadata("design:returntype", void 0)
], CheckboxBase.prototype, "onCheckedChanged", null);
CheckboxBase = __decorate([
    Component({})
], CheckboxBase);
export { CheckboxBase };
//# sourceMappingURL=Checkbox.base.js.map