import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Icon } from '../../Icon';
import { Image } from '../../Image';
const getClassNames = classNamesFunction();
let ChoiceGroupOptionBase = class ChoiceGroupOptionBase extends BaseComponent {
    get classNames() {
        const { styles, theme, iconProps, imageSrc, checked, disabled, imageSize, focused } = this;
        return getClassNames(styles, {
            theme: theme,
            hasIcon: !!iconProps,
            hasImage: !!imageSrc,
            checked,
            disabled,
            imageIsLarge: !!imageSrc && (imageSize.width > 71 || imageSize.height > 71),
            imageSize,
            focused,
        });
    }
    render(h) {
        const { id, classNames, text, imageSrc, imageAlt, imageSize, selectedImageSrc, iconProps, disabled } = this;
        const _id = `ChoiceGroup${this.uid}`;
        const $input = h('input', {
            class: classNames.input,
            attrs: {
                id: `ChoiceGroup${this.uid}-${id}`,
                name: `ChoiceGroup${this.uid}`,
                type: 'radio',
            },
        });
        const $label = h('label', {
            class: classNames.field,
            attrs: {
                for: `ChoiceGroup${this.uid}-${id}`,
            },
        }, [
            imageSrc && h('div', { class: classNames.innerField }, [
                h('div', { class: classNames.imageWrapper }, [
                    h(Image, {
                        props: {
                            src: imageSrc,
                            alt: imageAlt,
                            ...imageSize,
                        },
                    }),
                ]),
                h('div', { class: classNames.selectedImageWrapper }, [
                    h(Image, {
                        props: {
                            src: selectedImageSrc,
                            alt: imageAlt,
                            ...imageSize,
                        },
                    }),
                ]),
            ]),
            iconProps && h('div', { class: classNames.innerField }, [
                h('div', { class: classNames.iconWrapper }, [
                    h(Icon, { props: iconProps }),
                ]),
            ]),
            (imageSrc || iconProps)
                ? h('div', { class: classNames.labelWrapper }, [
                    h('span', { staticClass: 'ms-ChoiceFieldLabel' }, this.$slots.default || text),
                ])
                : h('span', { staticClass: 'ms-ChoiceFieldLabel' }, this.$slots.default || text),
        ]);
        return h('div', { class: classNames.root }, [
            h('div', { class: classNames.choiceFieldWrapper }, [
                $input,
                $label,
            ]),
        ]);
    }
};
__decorate([
    Prop(),
    __metadata("design:type", String)
], ChoiceGroupOptionBase.prototype, "id", void 0);
__decorate([
    Prop(),
    __metadata("design:type", String)
], ChoiceGroupOptionBase.prototype, "text", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "iconProps", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageSrc", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "selectedImageSrc", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageAlt", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "checked", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "disabled", void 0);
__decorate([
    Prop({ default: () => ({ width: 32, height: 32 }) }),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageSize", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "focused", void 0);
ChoiceGroupOptionBase = __decorate([
    Component
], ChoiceGroupOptionBase);
export { ChoiceGroupOptionBase };
//# sourceMappingURL=ChoiceGroupOption.base.js.map