import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent';
import { getIconContent } from './FontIcon';
const getClassNames = classNamesFunction({
    // Icon is used a lot by other components.
    // It's likely to see expected cases which pass different className to the Icon.
    // Therefore setting a larger cache size.
    cacheSize: 100,
});
let Icon = class Icon extends StatelessComponent {
    render(h, context) {
        const { className, iconName, theme, styles } = context.props;
        const isPlaceholder = typeof iconName === 'string' && iconName.length === 0;
        const isImage = !!context.props.imageProps;
        const iconContent = getIconContent(iconName) || {};
        const children = iconContent.children;
        const { iconClassName } = iconContent;
        const classNames = getClassNames(styles, {
            theme,
            className,
            iconClassName,
            isImage,
            isPlaceholder,
        });
        const RootType = isImage ? 'span' : 'i';
        return h(RootType, {
            ...context.data,
            class: classNames.root,
            attrs: {
                'aria-hidden': 'true',
                'data-icon-name': iconName,
            },
        }, typeof children === 'function' ? [children(h)] : children);
    }
};
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], Icon.prototype, "iconName", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], Icon.prototype, "imageProps", void 0);
Icon = __decorate([
    Component
], Icon);
export default Icon;
//# sourceMappingURL=Icon.js.map