import { __decorate, __metadata } from "tslib";
import { mergeOverflows, ktpTargetFromSequences } from '../../utilities/keytips/KeytipUtils';
import { Callout } from '../Callout';
import { DirectionalHint } from '../ContextualMenu';
import { KeytipContent } from './KeytipContent';
import { getCalloutStyles, getCalloutOffsetStyles } from './Keytip.styles';
import BaseComponent from '../BaseComponent';
import { Prop } from 'vue-property-decorator';
/**
 * A callout corresponding to another Fabric component to describe a key sequence that will activate that component
 */
export class Keytip extends BaseComponent {
    render(h) {
        const { keySequences, offset, overflowSetSequence } = this;
        let { calloutProps } = this;
        let keytipTarget;
        // Take into consideration the overflow sequence
        if (overflowSetSequence) {
            keytipTarget = ktpTargetFromSequences(mergeOverflows(keySequences, overflowSetSequence));
        }
        else {
            keytipTarget = ktpTargetFromSequences(keySequences);
        }
        if (offset) {
            // Set callout to top-left corner, will be further positioned in
            // getCalloutOffsetStyles
            calloutProps = {
                ...calloutProps,
                coverTarget: true,
                directionalHint: DirectionalHint.topLeftEdge,
            };
        }
        if (!calloutProps || calloutProps.directionalHint === undefined) {
            // Default callout directional hint to BottomCenter
            calloutProps = {
                ...calloutProps,
                directionalHint: DirectionalHint.bottomCenter,
            };
        }
        return h(Callout, {
            attrs: {
                ...calloutProps,
                isBeakVisible: false,
                doNotLayer: true,
                minPagePadding: 0,
                styles: offset ? getCalloutOffsetStyles(offset) : getCalloutStyles,
                preventDismissOnScroll: true,
                target: keytipTarget,
            },
        }, [h(KeytipContent, { props: this.$props })]);
    }
}
__decorate([
    Prop({ type: Array, default: undefined }),
    __metadata("design:type", Array)
], Keytip.prototype, "keySequences", void 0);
__decorate([
    Prop({ type: Object, default: undefined }),
    __metadata("design:type", Object)
], Keytip.prototype, "offset", void 0);
__decorate([
    Prop({ type: Array, default: undefined }),
    __metadata("design:type", Array)
], Keytip.prototype, "overflowSetSequence", void 0);
__decorate([
    Prop({ type: Object, default: undefined }),
    __metadata("design:type", Object)
], Keytip.prototype, "calloutProps", void 0);
//# sourceMappingURL=Keytip.js.map