import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { MountingPortal } from 'portal-vue';
import { registerLayer, getDefaultTarget, unregisterLayer } from './Layer.notification';
import BaseComponent from '../BaseComponent';
import { getStyles } from './Layer.styles';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let LayerBase = class LayerBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.hasTarget = false;
    }
    get classNames() {
        const { className, theme } = this;
        return getClassNames(getStyles, {
            theme,
            className,
            isNotHost: !this.hostId,
        });
    }
    mounted() {
        this.createElement();
        if (this.hostId) {
            registerLayer(this.hostId, this.createElement);
        }
    }
    beforeDestroy() {
        const { hostId } = this;
        if (this.hostId) {
            unregisterLayer(this.hostId, this.createElement);
        }
    }
    createElement() {
        const doc = this.$el.ownerDocument;
        const host = this.getHost();
        if (!doc || !host) {
            this.hasTarget = false;
            return;
        }
        this.hasTarget = true;
    }
    getHost() {
        const doc = this.$el.ownerDocument;
        if (!doc) {
            return undefined;
        }
        if (this.hostId) {
            return doc.getElementById(this.hostId);
        }
        else {
            const defaultHostSelector = getDefaultTarget();
            return defaultHostSelector
                ? doc.querySelector(defaultHostSelector)
                : doc.body;
        }
    }
    render(h) {
        if (!this.hasTarget)
            return;
        const { classNames, hostId, append } = this;
        return h(MountingPortal, {
            props: {
                mountTo: hostId ? `#${hostId}` : 'body',
                append,
            },
        }, [
            h('div', { class: classNames.root }, [
                h('div', { class: classNames.content }, [
                    this.$scopedSlots.default && this.$scopedSlots.default({}),
                ]),
            ]),
        ]);
    }
};
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], LayerBase.prototype, "hostId", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], LayerBase.prototype, "append", void 0);
LayerBase = __decorate([
    Component
], LayerBase);
export { LayerBase };
//# sourceMappingURL=Layer.base.js.map