import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
// if the percentComplete is near 0, don't animate it.
// This prevents animations on reset to 0 scenarios
const ZERO_THRESHOLD = 0.01;
let ProgressIndicatorBase = class ProgressIndicatorBase extends BaseComponent {
    get internalPercentComplete() {
        return typeof this.percentComplete === 'number'
            ? Math.min(100, Math.max(0, this.percentComplete * 100))
            : undefined;
    }
    get classNames() {
        const { styles, theme, className, internalPercentComplete, barHeight } = this;
        return getClassNames(styles, {
            theme: theme,
            className,
            barHeight,
            indeterminate: internalPercentComplete === undefined,
        });
    }
    get progressBarStyles() {
        const { internalPercentComplete } = this;
        return {
            width: internalPercentComplete !== undefined ? internalPercentComplete + '%' : undefined,
            transition: internalPercentComplete !== undefined && internalPercentComplete < ZERO_THRESHOLD ? 'none' : undefined,
        };
    }
    render(h) {
        const { classNames, label, progressHidden, progressBarStyles, description } = this;
        const $label = label && h('div', { class: classNames.itemName }, label);
        const $progress = !progressHidden &&
            h('div', { class: classNames.itemProgress }, [
                h('div', { class: classNames.progressTrack }),
                h('div', { class: classNames.progressBar, style: progressBarStyles }),
            ]);
        const $description = description && h('div', { class: classNames.itemDescription }, description);
        return h('div', { class: classNames.root }, [
            $label,
            $progress,
            $description,
        ]);
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ProgressIndicatorBase.prototype, "progressHidden", void 0);
__decorate([
    Prop({ type: Number, default: undefined }),
    __metadata("design:type", Number)
], ProgressIndicatorBase.prototype, "percentComplete", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ProgressIndicatorBase.prototype, "label", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ProgressIndicatorBase.prototype, "description", void 0);
__decorate([
    Prop({ type: Number, default: 2 }),
    __metadata("design:type", Number)
], ProgressIndicatorBase.prototype, "barHeight", void 0);
ProgressIndicatorBase = __decorate([
    Component
], ProgressIndicatorBase);
export { ProgressIndicatorBase };
//# sourceMappingURL=ProgressIndicator.base.js.map