import { __decorate, __metadata } from "tslib";
import { classNamesFunction, memoizeFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../../StatelessComponent';
import { Component, Prop } from 'vue-property-decorator';
import { ShimmerElementsDefaultHeights, ShimmerElementType } from '../Shimmer.types';
import { ShimmerLine } from '../ShimmerLine/ShimmerLine';
import { ShimmerCircle } from '../ShimmerCircle/ShimmerCircle';
import { ShimmerGap } from '../ShimmerGap/ShimmerGap';
import { h } from '../../../renderFunction';
const getClassNames = classNamesFunction();
let ShimmerElementsGroupBase = class ShimmerElementsGroupBase extends StatelessComponent {
    render(h, ctx) {
        const { styles, width, shimmerElements, rowHeight = findMaxElementHeight(shimmerElements || []), flexWrap = false, theme, backgroundColor, } = ctx.props;
        const classNames = getClassNames(styles, {
            theme: theme,
            flexWrap,
        });
        return h('div', {
            class: classNames.root,
            style: { width },
        }, [
            getRenderedElements(shimmerElements, backgroundColor, rowHeight),
        ]);
    }
};
__decorate([
    Prop({ type: Array, default: undefined }),
    __metadata("design:type", Array)
], ShimmerElementsGroupBase.prototype, "shimmerElements", void 0);
__decorate([
    Prop({ type: String, default: 'auto' }),
    __metadata("design:type", String)
], ShimmerElementsGroupBase.prototype, "width", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ShimmerElementsGroupBase.prototype, "flexWrap", void 0);
ShimmerElementsGroupBase = __decorate([
    Component
], ShimmerElementsGroupBase);
export default ShimmerElementsGroupBase;
function getRenderedElements(shimmerElements, backgroundColor, rowHeight) {
    const renderedElements = shimmerElements
        ? shimmerElements.map(
        // false positive
        // eslint-disable-next-line array-callback-return
        (element, index) => {
            const { type, ...filteredElem } = element;
            const { verticalAlign, height } = filteredElem;
            const styles = getElementStyles(verticalAlign, type, height, backgroundColor, rowHeight);
            const props = {
                key: index,
                attrs: {
                    ...filteredElem,
                    styles,
                },
            };
            switch (element.type) {
                case ShimmerElementType.circle:
                    return h(ShimmerCircle, props);
                case ShimmerElementType.gap:
                    return h(ShimmerGap, props);
                case ShimmerElementType.line:
                    return h(ShimmerLine, props);
            }
        })
        : h(ShimmerLine, {
            attrs: {
                height: ShimmerElementsDefaultHeights.line,
            },
        });
    return renderedElements;
}
const getElementStyles = memoizeFunction((verticalAlign, elementType, elementHeight, backgroundColor, rowHeight) => {
    const dif = rowHeight && elementHeight ? rowHeight - elementHeight : 0;
    let borderStyle;
    if (!verticalAlign || verticalAlign === 'center') {
        borderStyle = {
            borderBottomWidth: `${dif ? Math.floor(dif / 2) : 0}px`,
            borderTopWidth: `${dif ? Math.ceil(dif / 2) : 0}px`,
        };
    }
    else if (verticalAlign && verticalAlign === 'top') {
        borderStyle = {
            borderBottomWidth: `${dif}px`,
            borderTopWidth: `0px`,
        };
    }
    else if (verticalAlign && verticalAlign === 'bottom') {
        borderStyle = {
            borderBottomWidth: `0px`,
            borderTopWidth: `${dif}px`,
        };
    }
    if (backgroundColor) {
        switch (elementType) {
            case ShimmerElementType.circle:
                return {
                    root: { ...borderStyle, borderColor: backgroundColor },
                    svg: { fill: backgroundColor },
                };
            case ShimmerElementType.gap:
                return {
                    root: { ...borderStyle, borderColor: backgroundColor, backgroundColor: backgroundColor },
                };
            case ShimmerElementType.line:
                return {
                    root: { ...borderStyle, borderColor: backgroundColor },
                    topLeftCorner: { fill: backgroundColor },
                    topRightCorner: { fill: backgroundColor },
                    bottomLeftCorner: { fill: backgroundColor },
                    bottomRightCorner: { fill: backgroundColor },
                };
        }
    }
    return {
        root: borderStyle,
    };
});
/**
 * User should not worry to provide which of the elements is the highest so we do the calculation for him.
 * Plus if user forgot to specify the height we assign their defaults.
 */
function findMaxElementHeight(shimmerElements) {
    const shimmerElementsDefaulted = shimmerElements.map((element) => {
        switch (element.type) {
            case ShimmerElementType.circle:
                if (!element.height) {
                    element.height = ShimmerElementsDefaultHeights.circle;
                }
                break;
            case ShimmerElementType.line:
                if (!element.height) {
                    element.height = ShimmerElementsDefaultHeights.line;
                }
                break;
            case ShimmerElementType.gap:
                if (!element.height) {
                    element.height = ShimmerElementsDefaultHeights.gap;
                }
                break;
        }
        return element;
    });
    const rowHeight = shimmerElementsDefaulted.reduce((acc, next) => {
        return next.height ? (next.height > acc ? next.height : acc) : acc;
    }, 0);
    return rowHeight;
}
//# sourceMappingURL=ShimmerElementsGroup.base.js.map