import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import { Icon } from '../Icon';
import BaseComponent from '../BaseComponent';
import { IconButton } from '../Button/IconButton/IconButton';
import { Position } from '../../utilities/positioning';
import { calculatePrecision, classNamesFunction, precisionRound, } from '@uifabric-vue/utilities';
import { getArrowButtonStyles } from './SpinButton.styles';
export var KeyboardSpinDirection;
(function (KeyboardSpinDirection) {
    KeyboardSpinDirection[KeyboardSpinDirection["down"] = -1] = "down";
    KeyboardSpinDirection[KeyboardSpinDirection["notSpinning"] = 0] = "notSpinning";
    KeyboardSpinDirection[KeyboardSpinDirection["up"] = 1] = "up";
})(KeyboardSpinDirection || (KeyboardSpinDirection = {}));
const getClassNames = classNamesFunction();
let SpinButtonBase = class SpinButtonBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.Position = Position;
        this.getArrowButtonStyles = getArrowButtonStyles;
        this.customUpArrowButtonStyles = {};
        this.customDownArrowButtonStyles = {};
        this.internalValue = this.value || this.defaultValue;
        this.INITIAL_STEP_DELAY = 400;
        this.STEP_DELAY = 75;
        this.isFocused = false;
        this.keyboardSpinDirection = KeyboardSpinDirection.notSpinning;
    }
    get classNames() {
        const { theme, styles, className, disabled, isFocused, keyboardSpinDirection, labelPosition } = this;
        return getClassNames(styles, {
            theme: theme,
            disabled,
            isFocused,
            keyboardSpinDirection,
            labelPosition,
            className,
        });
    }
    onValueChanged(value) {
        this.$emit('input', value);
    }
    updateValue(value) {
        const newValue = precisionRound(value, this.precision);
        this.internalValue = newValue;
        return newValue;
    }
    onIncrement() {
        const newValue = Math.min(this.internalValue + this.step, this.max);
        return this.updateValue(newValue);
    }
    onDecrement() {
        const newValue = Math.max(this.internalValue - this.step, this.min);
        return this.updateValue(newValue);
    }
    startSpin(dir) {
        let newValue = dir === 1 ? this.onIncrement() : this.onDecrement();
        newValue = precisionRound(newValue, this.precision);
        this.internalValue = newValue;
        this.timeout = setTimeout(() => {
            this.interval = setInterval(() => {
                let newValue = dir === 1 ? this.onIncrement() : this.onDecrement();
                newValue = precisionRound(newValue, this.precision);
                this.internalValue = newValue;
            }, this.STEP_DELAY);
        }, this.INITIAL_STEP_DELAY);
    }
    get precision() {
        const precision = Math.max(calculatePrecision(this.step), 0);
        return precision;
    }
    stopSpin() {
        clearTimeout(this.timeout);
        clearInterval(this.interval);
    }
    render(h) {
        const { theme, customUpArrowButtonStyles, customDownArrowButtonStyles, classNames, labelPosition, iconProps, label, internalValue } = this;
        const $label = h('div', { class: classNames.labelWrapper }, [
            iconProps && h(Icon, {
                class: classNames.icon,
                props: {
                    ...iconProps,
                },
            }),
            h('Label', {
                class: classNames.label,
                attrs: {
                    for: `SpinButton${this.uid}`,
                },
            }, label),
        ]);
        const $spinButtonWrapper = h('div', { class: classNames.spinButtonWrapper }, [
            h('input', {
                class: classNames.input,
                attrs: {
                    id: `SpinButton${this.uid}`,
                    value: internalValue,
                    type: 'text',
                    role: 'spinbutton',
                },
                on: {
                    focus: () => (this.isFocused = true),
                    blur: () => (this.isFocused = false),
                    onput: ev => (this.internalValue = +(ev.target.value || 0)),
                },
            }),
            h('span', { class: classNames.arrowBox }, [
                h(IconButton, {
                    staticClass: 'ms-UpButton',
                    props: {
                        styles: getArrowButtonStyles(theme, true, customUpArrowButtonStyles),
                        iconProps: { iconName: 'ChevronUpSmall' },
                    },
                    nativeOn: {
                        mousedown: () => this.startSpin(1),
                        mouseup: () => this.stopSpin(),
                    },
                }),
                h(IconButton, {
                    staticClass: 'ms-DownButton',
                    props: {
                        styles: getArrowButtonStyles(theme, false, customDownArrowButtonStyles),
                        iconProps: { iconName: 'ChevronDownSmall' },
                    },
                    nativeOn: {
                        mousedown: () => this.startSpin(-1),
                        mouseup: () => this.stopSpin(),
                    },
                }),
            ]),
        ]);
        return h('div', { class: classNames.root }, [
            (labelPosition !== Position.bottom && (iconProps || label)) && $label,
            $spinButtonWrapper,
            (labelPosition === Position.bottom && (iconProps || label)) && $label,
        ]);
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], SpinButtonBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], SpinButtonBase.prototype, "required", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "defaultValue", void 0);
__decorate([
    Prop({ type: Number, default: null }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "value", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], SpinButtonBase.prototype, "label", void 0);
__decorate([
    Prop({ type: Number, default: Position.start }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "labelPosition", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "min", void 0);
__decorate([
    Prop({ type: Number, default: 10 }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "max", void 0);
__decorate([
    Prop({ type: Number, default: 1 }),
    __metadata("design:type", Number)
], SpinButtonBase.prototype, "step", void 0);
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], SpinButtonBase.prototype, "iconProps", void 0);
__decorate([
    Watch('internalValue'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], SpinButtonBase.prototype, "onValueChanged", null);
SpinButtonBase = __decorate([
    Component
], SpinButtonBase);
export { SpinButtonBase };
//# sourceMappingURL=SpinButton.base.js.map