import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch, Model } from 'vue-property-decorator';
import { Label } from '../Label';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
// import { defineComponent, ref, reactive } from '@vue/composition-api'
// export default defineComponent({
//   model: {
//     prop: 'checked',
//     event: 'input',
//   },
//   props: {
//     disabled: { type: Boolean, default: false },
//     checked: { type: Boolean, default: false },
//     defaultChecked: { type: Boolean, default: false },
//     label: { type: String, default: '' },
//     inlineLabel: { type: Boolean, default: false },
//     onText: { type: String, default: null },
//     offText: { type: String, default: null },
//   },
//   setup (props) {
//     console.log(props)
//     return () => <div>test</div>
//   },
// })
let ToggleBase = class ToggleBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalChecked = this.defaultChecked || this.checked;
    }
    onCheckedChanged(checked) {
        this.internalChecked = checked;
    }
    get classNames() {
        const { theme, className, disabled, internalChecked, inlineLabel, onText, offText } = this;
        return getClassNames(this.styles, {
            theme: theme,
            className: className,
            disabled: disabled,
            checked: internalChecked,
            inlineLabel: inlineLabel,
            onOffMissing: !onText && !offText,
        });
    }
    render(h) {
        const { classNames, internalChecked, disabled, label, onText, offText } = this;
        const id = `Toggle${this.uid}`;
        const $label = h(Label, {
            class: classNames.label,
            attrs: {
                for: id,
            },
        }, this.$scopedSlots.label ? [
            this.$scopedSlots.label({ checked: internalChecked, disabled, label }),
        ] : label);
        const $pill = h('button', {
            ref: 'toggleButton',
            class: classNames.pill,
            attrs: {
                id: id,
            },
            on: {
                click: this.onClick,
            },
        }, [
            h('div', { class: classNames.thumb }),
        ]);
        const $stateLabel = ((internalChecked && onText) || (!internalChecked && offText)) && h(Label, {
            class: classNames.text,
            attrs: {
                for: id,
            },
        }, internalChecked ? onText : offText);
        const $container = h('div', { class: classNames.container }, [
            $pill,
            $stateLabel,
        ]);
        return h('div', { class: classNames.root }, [
            $label,
            $container,
        ]);
    }
    focus() {
        this.$refs.toggleButton.focus();
    }
    onClick() {
        if (this.disabled)
            return;
        this.internalChecked = !this.internalChecked;
        this.$emit('input', this.internalChecked);
    }
};
__decorate([
    Model('input', { type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ToggleBase.prototype, "checked", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ToggleBase.prototype, "label", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ToggleBase.prototype, "defaultChecked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ToggleBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ToggleBase.prototype, "inlineLabel", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ToggleBase.prototype, "onText", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ToggleBase.prototype, "offText", void 0);
__decorate([
    Watch('checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean]),
    __metadata("design:returntype", void 0)
], ToggleBase.prototype, "onCheckedChanged", null);
ToggleBase = __decorate([
    Component
], ToggleBase);
export { ToggleBase };
//# sourceMappingURL=Toggle.base.js.map